==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/invoice_styles_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoiceStylesController < AccountsManagementController
    # GET /documents/invoice_styles
    # GET /documents/invoice_styles.json
    def index
      @documents_invoice_styles = Documents::InvoiceStyle.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_invoice_styles }
      end
    end

    # GET /documents/invoice_styles/1
    # GET /documents/invoice_styles/1.json
    def show
      @documents_invoice_style = Documents::InvoiceStyle.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_invoice_style }
      end
    end

    # GET /documents/invoice_styles/new
    # GET /documents/invoice_styles/new.json
    def new
      @documents_invoice_style = Documents::InvoiceStyle.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_invoice_style }
      end
    end

    # GET /documents/invoice_styles/1/edit
    def edit
      @documents_invoice_style = Documents::InvoiceStyle.find(params[:id])
    end

    # POST /documents/invoice_styles
    # POST /documents/invoice_styles.json
    def create
      @documents_invoice_style = Documents::InvoiceStyle.new(params[:documents_invoice_style])

      respond_to do |format|
        if @documents_invoice_style.save
          format.html { redirect_to @documents_invoice_style, :notice => 'Invoice style was successfully created.' }
          format.json { render :json => @documents_invoice_style, :status => :created, :location => @documents_invoice_style }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_invoice_style.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoice_styles/1
    # PUT /documents/invoice_styles/1.json
    def update
      @documents_invoice_style = Documents::InvoiceStyle.find(params[:id])

      respond_to do |format|
        if @documents_invoice_style.update_attributes(params[:documents_invoice_style])
          format.html { redirect_to @documents_invoice_style, :notice => 'Invoice style was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_invoice_style.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoice_styles/1
    # DELETE /documents/invoice_styles/1.json
    def destroy
      @documents_invoice_style = Documents::InvoiceStyle.find(params[:id])
      @documents_invoice_style.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoice_styles_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/invoice_styles_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoiceStylesController < AccountsManagementController
    # GET /documents/invoice_styles
    # GET /documents/invoice_styles.json
    def index
      @documents_invoice_styles = Documents::InvoiceStyle.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_invoice_styles }
      end
    end

    # GET /documents/invoice_styles/1
    # GET /documents/invoice_styles/1.json
    def show
      @documents_invoice_style = Documents::InvoiceStyle.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_invoice_style }
      end
    end

    # GET /documents/invoice_styles/new
    # GET /documents/invoice_styles/new.json
    def new
      @documents_invoice_style = Documents::InvoiceStyle.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_invoice_style }
      end
    end

    # GET /documents/invoice_styles/1/edit
    def edit
      @documents_invoice_style = Documents::InvoiceStyle.find(params[:id])
    end

    # POST /documents/invoice_styles
    # POST /documents/invoice_styles.json
    def create
      @documents_invoice_style = Documents::InvoiceStyle.new(params[:documents_invoice_style])

      respond_to do |format|
        if @documents_invoice_style.save
          format.html { redirect_to @documents_invoice_style, notice: 'Invoice style was successfully created.' }
          format.json { render json: @documents_invoice_style, status: :created, location: @documents_invoice_style }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_invoice_style.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoice_styles/1
    # PUT /documents/invoice_styles/1.json
    def update
      @documents_invoice_style = Documents::InvoiceStyle.find(params[:id])

      respond_to do |format|
        if @documents_invoice_style.update_attributes(params[:documents_invoice_style])
          format.html { redirect_to @documents_invoice_style, notice: 'Invoice style was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_invoice_style.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoice_styles/1
    # DELETE /documents/invoice_styles/1.json
    def destroy
      @documents_invoice_style = Documents::InvoiceStyle.find(params[:id])
      @documents_invoice_style.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoice_styles_url }
        format.json { head :no_content }
      end
    end
  end
end
